@@ -6,12 +6,12 @@ use lib '../../lib';
 use SOAP::WSDL::XSD::Typelib::ComplexType;
 use base ('SOAP::WSDL::XSD::Typelib::ComplexType');
 
-my %MyTestName_of;                      # no :ATTR - _factory takes care of
+my %MyTestName_of :ATTR(:get<MyTestName>); 
 
 __PACKAGE__->_factory(
     [ qw(MyTestName) ],                # order
     { MyTestName => \%MyTestName_of },  # attribute lookup map
-    { MyTestName => 'MyElement' }       # class name lookup map
+    { MyTestName => 'SOAP::WSDL::XSD::Typelib::Builtin::string' }       # class name lookup map
 );
 
 sub get_xmlns { 'urn:Test' };
